==> jc-1.4.0.tar.gz: javax/swing/InputVerifier.h <==
// public abstract class javax.swing.InputVerifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c5d7b5e9ce743879 javax_swing_InputVerifier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_InputVerifier_H_
#define _JC_javax_swing_InputVerifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_InputVerifier$sub_refs	_jc_javax_swing_InputVerifier$sub_refs;
typedef struct _jc_javax_swing_InputVerifier$sub_nonrefs	_jc_javax_swing_InputVerifier$sub_nonrefs;
typedef struct _jc_javax_swing_InputVerifier$refs	_jc_javax_swing_InputVerifier$refs;
typedef struct _jc_javax_swing_InputVerifier$nonrefs	_jc_javax_swing_InputVerifier$nonrefs;
typedef struct _jc_javax_swing_InputVerifier$object	_jc_javax_swing_InputVerifier$object;

typedef const struct _jc_javax_swing_InputVerifier$vmethods	_jc_javax_swing_InputVerifier$vmethods;
typedef const struct _jc_javax_swing_InputVerifier$vtable	_jc_javax_swing_InputVerifier$vtable;
typedef const struct _jc_javax_swing_InputVerifier$vtype	_jc_javax_swing_InputVerifier$vtype;

// Constructors
extern void _jc_javax_swing_InputVerifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_InputVerifier$object *);

// Virtual methods
extern jboolean _jc_javax_swing_InputVerifier$method$shouldYieldFocus$36706b0573f50e12(_jc_env *, struct _jc_javax_swing_InputVerifier$object *, struct _jc_javax_swing_JComponent$object *);
extern jboolean _jc_javax_swing_InputVerifier$method$verify$b987b9703ca86d20(_jc_env *, struct _jc_javax_swing_InputVerifier$object *, struct _jc_javax_swing_JComponent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_InputVerifier$method_info$shouldYieldFocus$36706b0573f50e12;
extern _jc_method _jc_javax_swing_InputVerifier$method_info$verify$b987b9703ca86d20;

// Virtual methods structure
struct _jc_javax_swing_InputVerifier$vmethods {
	jboolean	(*shouldYieldFocus$36706b0573f50e12)(_jc_env *, struct _jc_javax_swing_InputVerifier$object *, struct _jc_javax_swing_JComponent$object *);
	jboolean	(*verify$b987b9703ca86d20)(_jc_env *, struct _jc_javax_swing_InputVerifier$object *, struct _jc_javax_swing_JComponent$object *);
};

// Vtable
struct _jc_javax_swing_InputVerifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputVerifier$vmethods	javax_swing_InputVerifier;
};

// Vtype
struct _jc_javax_swing_InputVerifier$vtype {
	_jc_type			type;
	_jc_javax_swing_InputVerifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_InputVerifier$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_InputVerifier$refs {
    _jc_javax_swing_InputVerifier$sub_refs	javax_swing_InputVerifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_InputVerifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_InputVerifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputVerifier$sub_nonrefs	javax_swing_InputVerifier;
};

// Object instance structure
struct _jc_javax_swing_InputVerifier$object {
	_jc_javax_swing_InputVerifier$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_InputVerifier$vtype	*vtype;
	_jc_javax_swing_InputVerifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_InputVerifier$vtype _jc_javax_swing_InputVerifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_InputVerifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_InputVerifier$class_object;

#endif	/* _JC_javax_swing_InputVerifier_H_ */

==> jc-1.4.6.tar.gz: javax/swing/InputVerifier.h <==
// public abstract class javax.swing.InputVerifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c5d7b5e9ce743879 javax_swing_InputVerifier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_InputVerifier_H_
#define _JC_javax_swing_InputVerifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_InputVerifier$sub_refs	_jc_javax_swing_InputVerifier$sub_refs;
typedef struct _jc_javax_swing_InputVerifier$sub_nonrefs	_jc_javax_swing_InputVerifier$sub_nonrefs;
typedef struct _jc_javax_swing_InputVerifier$refs	_jc_javax_swing_InputVerifier$refs;
typedef struct _jc_javax_swing_InputVerifier$nonrefs	_jc_javax_swing_InputVerifier$nonrefs;
typedef struct _jc_javax_swing_InputVerifier$object	_jc_javax_swing_InputVerifier$object;

typedef const struct _jc_javax_swing_InputVerifier$vmethods	_jc_javax_swing_InputVerifier$vmethods;
typedef const struct _jc_javax_swing_InputVerifier$vtable	_jc_javax_swing_InputVerifier$vtable;
typedef const struct _jc_javax_swing_InputVerifier$vtype	_jc_javax_swing_InputVerifier$vtype;

// Constructors
extern void _jc_javax_swing_InputVerifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_InputVerifier$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_InputVerifier$method$shouldYieldFocus$36706b0573f50e12(_jc_env *, struct _jc_javax_swing_InputVerifier$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_InputVerifier$method$verify$b987b9703ca86d20(_jc_env *, struct _jc_javax_swing_InputVerifier$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_InputVerifier$method_info$shouldYieldFocus$36706b0573f50e12;
extern _jc_method _jc_javax_swing_InputVerifier$method_info$verify$b987b9703ca86d20;

// Virtual methods structure
struct _jc_javax_swing_InputVerifier$vmethods {
	jboolean	(*shouldYieldFocus$36706b0573f50e12)(_jc_env *, struct _jc_javax_swing_InputVerifier$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
	jboolean	(*verify$b987b9703ca86d20)(_jc_env *, struct _jc_javax_swing_InputVerifier$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_InputVerifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputVerifier$vmethods	javax_swing_InputVerifier;
};

// Vtype
struct _jc_javax_swing_InputVerifier$vtype {
	_jc_type			type;
	_jc_javax_swing_InputVerifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_InputVerifier$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_InputVerifier$refs {
    _jc_javax_swing_InputVerifier$sub_refs	javax_swing_InputVerifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_InputVerifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_InputVerifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputVerifier$sub_nonrefs	javax_swing_InputVerifier;
};

// Object instance structure
struct _jc_javax_swing_InputVerifier$object {
	_jc_javax_swing_InputVerifier$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_InputVerifier$vtype	*vtype;
	_jc_javax_swing_InputVerifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_InputVerifier$vtype _jc_javax_swing_InputVerifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_InputVerifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_InputVerifier$class_object;

#endif	/* _JC_javax_swing_InputVerifier_H_ */
